Concatenates the records of the same variable from multiple netCDF files along the unlimited dimension and writes the result to a new file.
Details
All files must contain the selected variable and must be compatible in all non-unlimited dimensions. The unlimited dimension is appended in the order given by `filenames`.
Examples
if (FALSE) { # \dontrun{
nc_rcat(
filenames = c("part1.nc", "part2.nc", "part3.nc"),
varid = "temp",
output = "combined.nc"
)
} # }