Change variable compression settings in a netCDF object
Source:R/nctools-auxiliar.R
ncvar_change_compression.RdModifies the compression setting of one or more variables in an open netCDF object.
Arguments
- nc
An open netCDF connection created with [ncdf4::nc_open()].
- varid
Variable identifier. This can be a character string giving the variable name, or an object of class `ncvar4`. If `NA`, the compression setting is changed for all variables in the file.
- compression
Numeric compression level to assign.